<?php
/*
Plugin Name: Recent Links
Version: 1.4
Plugin URI: http://rebelpixel.com/projects/wp-recent-links/
Description: A linklog plugin for WordPress, allowing you to have your own blog of links without the need for another wp-powered weblog or (gasp!) another weblog software. More information at the <a href="http://rebelpixel.com/projects/wp-recent-links/">project's page</a>.
Author: Markku Seguerra
Author URI: http://rebelpixel.com/
*/



/* =========================================================================
                                                    ++++++++++++++++++++++++
                                                    ++  rp_recentlinks()  ++
                                                    ++++++++++++++++++++++++
                                                          by Markku Seguerra
                                                       http://rebelpixel.com

Displays the most recent links added to your linklog.

$limit
    The number of links to display.
    Defaults to 12.

$use_permalink
    Use permalinks for your links? True or False.
    Defaults to false.

$permalink_beginning
    Permalink at the beginning of the link? True or False.
    Defaults to True.

$permalink_icon
    Permalink icon used.
    Defaults to the commonly-used '#' character.

$inline_caption
    Use inline captions, in addition to the title attribute.
    Defaults to false.

$date_append
    Date format of the date string added for a link's title attribute.
    This is based on PHP's date() function.
    Defaults to 'F j', which displays March 22.
    Other suggested formats:
        jS M Y @ g A    ==>     22nd Mar 2004 @ 5 PM
        M j             ==>     Mar 22

$before
    String to add before the link-formatted text.
    Defaults to "<li>"

$after
    String to add after the link-formatted text.
    Defaults to "</li>"

$between
    String to add after a link. This is added after the $after string.
    Defaults to "\n" (newline)

========================================================================= */
// 2004-05-18 16:57:11
function rp_recentlinks($limit = 12,
                        $use_permalink = false,
                        $permalink_beginning = true,
                        $permalink_icon = '#',
                        $inline_caption = false,
                        $date_append = 'F j',

                        $before = '<li>',
                        $after = '</li>',
                        $between = "\n")
{
    global $table_prefix, $wpdb;

    $tablerecentlinks = $table_prefix.'recentlinks';
    $a_tag = '[a]';
    $a_tag2 = '[/a]';
    $time_difference = get_settings('time_difference');

    if ('' != $limit) {
        $limit = (int) $limit;
        $limit = " LIMIT $limit";
    }

    $now = date('Y-m-d H:i:s',(time() + ($time_difference * 3600)));
    $sql = "SELECT ID, link_url, link_text, link_caption, link_rel, link_target, link_visible, date_added FROM $tablerecentlinks WHERE date_added < '$now' AND link_visible = 'Y' ORDER BY date_added DESC $limit";

    $links = $wpdb->get_results($sql);

    if ($links) {

        $out = '';
        foreach ($links as $link) {

            $link->link_text = stripslashes($link->link_text);
            $link->link_url = stripslashes($link->link_url);
            $link->link_caption = stripslashes($link->link_caption);
            $link->link_rel = stripslashes($link->link_rel);
            $link->link_target = stripslashes($link->link_target);

            $this_date = date($date_append, strtotime($link->date_added));

            if (strlen($link->link_caption) > 0) {
                $piped_caption = ' | '.$link->link_caption;
            } else {
                $piped_caption = '';
            }

            if (strlen($link->link_rel) == 0) {
                $rel = '';
            } else {
                $rel = ' rel="'.$link->link_rel.'"';
            }

            if (strlen($link->link_target) == 0) {
                $target = '';
            } else {
                $target = ' target="'.$link->link_target.'"';
            }


            if (  is_int(strpos($link->link_url, '&'))  &&  !strpos($link->link_url, '&')  &&  !strpos($link->link_url, '&')  ) {
                $link->link_url = str_replace('&', '&', $link->link_url);
            }


            if (  is_int(strpos($link->link_text, $a_tag))  &&  is_int(strpos($link->link_text, $a_tag2))  ) {
                $pos_open = strpos($link->link_text, $a_tag);
                $pos_close = strpos($link->link_text, $a_tag2, $pos_open);

                $prefix = substr($link->link_text, 0, $pos_open);
                $suffix = substr($link->link_text, $pos_close + strlen($a_tag2));

                $middle = substr($link->link_text, $pos_open + strlen($a_tag), $pos_close - ($pos_open + strlen($a_tag)));

                $new_link = $prefix.'<a href="'.$link->link_url.'" title="'.wptexturize($this_date.$piped_caption).'"'.$rel.$target.'>'.wptexturize($middle).'</a>'.$suffix;
            } else {
                $new_link = '<a href="'.$link->link_url.'" title="'.wptexturize($this_date.$piped_caption).'"'.$rel.$target.'>'.wptexturize($link->link_text).'</a>';
            }


            if ($use_permalink) {
                $siteurl = get_settings('siteurl');
                $rewrite = get_settings('permalink_structure');
                if (strlen($permalink_icon) == 0) {
                    $permalink_icon = '#';
                }
                if (strlen($rewrite) > 0) { // using mod_rewrite
                    $permalink_url = $siteurl.'/recent-links/'.date('Y/m', strtotime($link->date_added)).'/#rlink-'.$link->ID;
                } else {
                    $permalink_url = $siteurl.'/wp-recent-links.php?y='.date('Y', strtotime($link->date_added)).'&m='.date('m', strtotime($link->date_added)).'#rlink-'.$link->ID;
                }

                if ($permalink_beginning) {
                    $new_link = '<a href="'.$permalink_url.'" title="Permalink to this resource on this site.">'.$permalink_icon.'</a> '.$new_link;
                } else {
                    $new_link = $new_link.' <a href="'.$permalink_url.'" title="Permalink to this resource on this site.">'.$permalink_icon.'</a>';
                }
            }


            if ($inline_caption) {
                $new_link = $new_link.'<br />'.wptexturize($link->link_caption);
            }


            $out .= $before.$new_link.$after.$between;

        }
    }
    echo $out;
}












/* =========================================================================
                                       +++++++++++++++++++++++++++++++++++++
                                       ++  rp_recentlinks_archives_url()  ++
                                       +++++++++++++++++++++++++++++++++++++
                                                          by Markku Seguerra
                                                       http://rebelpixel.com

Displays the URL of the archives page for the
recent links plugin.

========================================================================= */
function rp_recentlinks_archives_url()
{
    $siteurl = get_settings('siteurl');
    $rewrite = get_settings('permalink_structure');

    if (strlen($rewrite) > 0) { // using mod_rewrite
        echo $siteurl.'/recent-links/';
    } else {
        echo $siteurl.'/wp-recent-links.php';
    }
}















/* =========================================================================
                                           +++++++++++++++++++++++++++++++++
                                           ++  rp_recentlinks_rss2_url()  ++
                                           +++++++++++++++++++++++++++++++++
                                                          by Markku Seguerra
                                                       http://rebelpixel.com

Displays the URL of the RSS 2 feed for the
recent links plugin.

========================================================================= */
// 2004-05-18 17:07:04
function rp_recentlinks_rss2_url()
{
    $siteurl = get_settings('siteurl');
    $rewrite = get_settings('permalink_structure');

    if (strlen($rewrite) > 0) { // using mod_rewrite
        echo $siteurl.'/recent-links/feed/';
    } else {
        echo $siteurl.'/wp-recent-links-rss2.php';
    }
}









/* =========================================================================
                                              ++++++++++++++++++++++++++++++
                                              ++  rp_recentlinks_month()  ++
                                              ++++++++++++++++++++++++++++++
                                                          by Markku Seguerra
                                                       http://rebelpixel.com

Displays the links for the given month.

$limit
    The number of links to display.
    Defaults to 12.

$show_link_count
    Show link count for given month? True or False.
    Defaults to false.

$use_permalink
    Use permalinks for your links? True or False.
    Defaults to false.

$permalink_beginning
    Permalink at the beginning of the link? True or Flase.
    Defaults to True.

$permalink_icon
    Permalink icon used.
    Defaults to the commonly-used '#' character.

$inline_caption
    Use inline captions, in addition to the title attribute.
    Defaults to false.

$date_append
    Date format of the date string added for a link's title attribute.
    This is based on PHP's date() function.
    Defaults to 'F j', which displays March 22.
    Other suggested formats:
        jS M Y @ g A    ==>     22nd Mar 2004 @ 5 PM
        M j             ==>     Mar 22
$before
    String to add before the link-formatted text.
    Defaults to "<li>"

$after
    String to add after the link-formatted text.
    Defaults to "</li>"

$between
    String to add after a link. This is added after the $after string.
    Defaults to "\n" (newline)

========================================================================= */
// 2004-05-18 17:06:57
function rp_recentlinks_month($limit = '',
                                $show_link_count = false,
                                $use_permalink = false,
                                $permalink_beginning = true,
                                $permalink_icon = '#',
                                $inline_caption = false,
                                $date_append = 'F j',
                                $before = '<li>',
                                $after = '</li>',
                                $between = "\n")
{
    global $table_prefix, $wpdb;
    $tablerecentlinks = $table_prefix.'recentlinks';
    $a_tag = '[a]';
    $a_tag2 = '[/a]';
    $time_difference = get_settings('time_difference');

    $y = strip_tags($_REQUEST['y']);
    $m = strip_tags($_REQUEST['m']);

    if ('' != $limit) {
        $limit = (int) $limit;
        $limit = " LIMIT $limit";
    }


    $now = date('Y-m-d H:i:s',(time() + ($time_difference * 3600)));

    $links = $wpdb->get_results("SELECT ID, link_url, link_text, link_caption, link_rel, link_target, link_visible, date_added FROM $tablerecentlinks WHERE date_added < '$now' AND link_visible = 'Y' AND YEAR(date_added) = '$y' AND MONTH(date_added) = '$m' ORDER BY date_added DESC" . $limit);

    if ($links) {

        $out = '';
        foreach ($links as $link) {

            $link->link_text = stripslashes($link->link_text);
            $link->link_url = stripslashes($link->link_url);
            $link->link_caption = stripslashes($link->link_caption);
            $link->link_rel = stripslashes($link->link_rel);
            $link->link_target = stripslashes($link->link_target);

            $this_date = date($date_append, strtotime($link->date_added));

            if (strlen($link->link_caption) > 0) {
                $piped_caption = ' | '.$link->link_caption;
            } else {
                $piped_caption = '';
            }

            if (strlen($link->link_rel) == 0) {
                $rel = '';
            } else {
                $rel = ' rel="'.$link->link_rel.'"';
            }
            if (strlen($link->link_target) == 0) {
                $target = '';
            } else {
                $target = ' target="'.$link->link_target.'"';
            }

            // ID for permalinks
            $id = ' id="rlink-'.$link->ID.'"';


            if (  is_int(strpos($link->link_url, '&'))  &&  !strpos($link->link_url, '&')  &&  !strpos($link->link_url, '&')  ) {
                $link->link_url = str_replace('&', '&', $link->link_url);
            }


            if (  is_int(strpos($link->link_text, $a_tag))  &&  is_int(strpos($link->link_text, $a_tag2))  ) {
                $pos_open = strpos($link->link_text, $a_tag);
                $pos_close = strpos($link->link_text, $a_tag2, $pos_open);

                $prefix = substr($link->link_text, 0, $pos_open);
                $suffix = substr($link->link_text, $pos_close + strlen($a_tag2));

                $middle = substr($link->link_text, $pos_open + strlen($a_tag), $pos_close - ($pos_open + strlen($a_tag)));

                $new_link = $prefix.'<a href="'.$link->link_url.'" title="'.wptexturize($this_date.$piped_caption).'"'.$rel.$target.$id.'>'.wptexturize($middle).'</a>'.$suffix;
            } else {
                $new_link = '<a href="'.$link->link_url.'" title="'.wptexturize($this_date.$piped_caption).'"'.$rel.$target.$id.'>'.wptexturize($link->link_text).'</a>';
            }


            if ($use_permalink) {
                $siteurl = get_settings('siteurl');
                $rewrite = get_settings('permalink_structure');
                if (strlen($permalink_icon) == 0) {
                    $permalink_icon = '#';
                }
                if (strlen($rewrite) > 0) { // using mod_rewrite
                    $permalink_url = $siteurl.'/recent-links/'.date('Y/m', strtotime($link->date_added)).'/#rlink-'.$link->ID;
                } else {
                    $permalink_url = $siteurl.'/wp-recent-links.php?y='.date('Y', strtotime($link->date_added)).'&m='.date('m', strtotime($link->date_added)).'#rlink-'.$link->ID;
                }


                if ($permalink_beginning) {
                    $new_link = '<a href="'.$permalink_url.'" title="Permalink to this resource on this site.">'.$permalink_icon.'</a> '.$new_link;
                } else {
                    $new_link = $new_link.' <a href="'.$permalink_url.'" title="Permalink to this resource on this site.">'.$permalink_icon.'</a>';
                }
            }

            if ($inline_caption) {
                $new_link = $new_link.'<br />'.wptexturize($link->link_caption);
            }


            $out .= $before.$new_link.$after.$between;

        }
    }
    echo $out;
}















/* =========================================================================
                                           +++++++++++++++++++++++++++++++++
                                           ++  rp_recentlinks_archives()  ++
                                           +++++++++++++++++++++++++++++++++
                                                          by Markku Seguerra
                                                       http://rebelpixel.com

Displays the monthly archives for the recent links plugin.

$limit
    The number of links to display.
    Defaults to '', which shows all.

$show_link_count
    Show link count for given month? True or False.
    Defaults to false.

$before
    String to add before the link-formatted text.
    Defaults to "<li>"

$after
    String to add after the link-formatted text.
    Defaults to "</li>"

$between
    String to add after a link. This is added after the $after string.
    Defaults to "\n" (newline)

========================================================================= */
function rp_recentlinks_archives($limit = '',
                                    $show_link_count = false,
                                    $before = '<li>',
                                    $after = '</li>',
                                    $between = "\n")
{
    global $table_prefix, $wpdb;
    $siteurl = get_settings('siteurl');
    $tablerecentlinks = $table_prefix.'recentlinks';
    $time_difference = get_settings('time_difference');

    $rewrite = get_settings('permalink_structure');

    if ('' != $limit) {
        $limit = (int) $limit;
        $limit = " LIMIT $limit";
    }


    $now = date('Y-m-d H:i:s',(time() + ($time_difference * 3600)));

    $arcresults = $wpdb->get_results("SELECT DISTINCT YEAR(date_added) AS `year`, MONTH(date_added) AS `month`, count(ID) as links, date_added FROM $tablerecentlinks WHERE date_added < '$now' AND link_visible = 'Y' GROUP BY YEAR(date_added), MONTH(date_added) ORDER BY date_added DESC" . $limit);

    if ($arcresults) {
        $out = '';
        foreach ($arcresults as $month) {
            if (strlen($rewrite) > 0) {
                $url = $siteurl.'/recent-links/'.date('Y/m/', strtotime($month->date_added));
            } else {
                $url = $siteurl.'/wp-recent-links.php?y='.date('Y', strtotime($month->date_added)).'&m='.date('m', strtotime($month->date_added));
            }

            if ($show_link_count) {
                $link_count = ' ('.$month->links.')';
            } else {
                $link_count = '';
            }

            $link = '<a href="'.$url.'" title="'.date('F Y', strtotime($month->date_added)).'">'.date('F Y', strtotime($month->date_added)).'</a>'. $link_count;

            $out .= $before.$link.$after.$between;
        }

    }
    echo $out;
}









function rp_recentlinks_home($default_days = 7)
{
    return rp_recentlinks_archive_page(7);
}





/* =========================================================================
                                           +++++++++++++++++++++++++++++++++
                                       ++  rp_recentlinks_archive_page()  ++
                                           +++++++++++++++++++++++++++++++++
                                                          by Markku Seguerra
                                                       http://rebelpixel.com

Displays links for the archive page (or current month).

$default_days
    The number of days of links to display.
    Defaults to 30.

========================================================================= */
function rp_recentlinks_archive_page($default_days = 30)
{
    global $table_prefix, $wpdb;

    $y = '';
    $m = '';
    $d = '';

    $tablerecentlinks = $table_prefix.'recentlinks';
    $a_tag = '[a]';
    $a_tag2 = '[/a]';

    if (strlen(get_settings('permalink_structure')) > 0) {
        $y = strval($_GET['y']);
        $m = strval($_GET['m']);
    } else {
        $y = strval(substr($_GET['m'], 0, 4));
        if (strlen($_GET['m']) > 4) {
            $m = strval(substr($_GET['m'], 4, 2));
        }
    }

    if (  strlen($y) == 4 && strlen($m) != 2 ) { //year
        $now       = $y.'-12-31 23:59:59';
        $last_day  = $y.'-01-01 00:00:00';
    } elseif (  strlen($y) == 4 && strlen($m) == 2 ) { //month
        if ( checkdate($m, '31', $y) ) {
            $now        = $y.'-'.$m.'-31 23:59:59';
            $last_day   = $y.'-'.$m.'-01 00:00:00';
        } elseif ( checkdate($m, '30', $y) ) {
            $now        = $y.'-'.$m.'-30 23:59:59';
            $last_day   = $y.'-'.$m.'-01 00:00:00';
        } elseif ( checkdate($m, '29', $y) ) {
            $now        = $y.'-'.$m.'-29 23:59:59';
            $last_day   = $y.'-'.$m.'-01 00:00:00';
        } else {
            $now        = $y.'-'.$m.'-28 23:59:59';
            $last_day   = $y.'-'.$m.'-01 00:00:00';
        }
    } else {
        $now = date('Y-m-d H:i:s',(time() + (get_settings('time_difference') * 3600)));
        $last_day = date('Y-m-d H:i:s',((time()-(3600*24*$default_days)) + (get_settings('time_difference') * 3600))); // last 30 days of links
    }


    $sql = "SELECT ID, link_url, link_text, link_caption, link_rel, link_target, link_visible, date_added FROM $tablerecentlinks WHERE date_added < '$now' AND date_added > '$last_day' AND link_visible = 'Y' ORDER BY date_added DESC";

    $links = $wpdb->get_results($sql);

    if ($links) {

        for ($i=0; $i < count($links); $i++) {
            $links[$i]->link_text = stripslashes($links[$i]->link_text);
            $links[$i]->link_url = stripslashes($links[$i]->link_url);
            $links[$i]->link_caption = stripslashes($links[$i]->link_caption);
            $links[$i]->link_rel = stripslashes($links[$i]->link_rel);
            $links[$i]->link_target = stripslashes($links[$i]->link_target);

            if (strlen(get_settings('permalink_structure')) > 0) { // using mod_rewrite
                $links[$i]->link_permalink = get_settings('siteurl').'/recent-links/'.date('Y/m', strtotime($links[$i]->date_added)).'/#rlink-'.$links[$i]->ID;
            } else {
                $links[$i]->link_permalink = get_settings('siteurl').'/wp-recent-links.php?y='.date('Y', strtotime($links[$i]->date_added)).'&m='.date('m', strtotime($links[$i]->date_added)).'#rlink-'.$links[$i]->ID;
            }

            if (  is_int(strpos($links[$i]->link_url, '&'))  &&  !strpos($links[$i]->link_url, '&')  &&  !strpos($links[$i]->link_url, '&')  ) {
                $links[$i]->link_url = str_replace('&', '&', $links[$i]->link_url);
            }

            $links[$i]->link_text = strip_tags($links[$i]->link_text);
            $links[$i]->link_text = str_replace($a_tag, '', $links[$i]->link_text);
            $links[$i]->link_text = str_replace($a_tag2, '', $links[$i]->link_text);

        }
    }

    return $links;
}

























/* undocumented yet, internal use only! */
function rp_recentlinks_inline_merge($entries = 7, $use_days = false, $cat_id = 0)
{
    global $table_prefix, $wpdb, $posts, $tablepost2cat;



    $cat_id = intval($cat_id);
    if ($cat_id > 0) {
        $sql = " SELECT post_id "
                ." FROM $tablepost2cat "
                ." WHERE category_id='$cat_id' "
                ." ORDER BY post_id ";
        $cat = $wpdb->get_results($sql);

        $cat_arr = array();
        foreach ($cat as $c) {
            $cat_arr[] = $c->post_id;
        }

    }





    $tablerecentlinks = $table_prefix.'recentlinks';
    $a_tag = '[a]';
    $a_tag2 = '[/a]';


    if ($use_days) {
        $__p = array();
        $i = 0;
        $day_counter = 0;
        $__prev_date = '';

        foreach ($posts as $post) {
            if ($i == 0) {
                $__p[] = $post;
                $__prev_date = $post->post_date;
                $day_counter++;
            } else {
                if (date('Y-m-d', strtotime($post->post_date)) == date('Y-m-d', strtotime($__prev_date))) {
                    $__p[] = $post;
                } else {
                    $__p[] = $post;
                    if ($cat_id == 0) {
                        $day_counter++;
                    } else {
                        if ($cat_id > 0 && !in_array($post->ID, $cat_arr)) {
                            $day_counter++;
                        }
                    }
                }
                $__prev_date = $post->post_date;
            }
            if ($day_counter == $entries) {
                break;
            }
            $i++;
        }
        $posts = $__p;

    } else {
        if (count($posts) > $entries) {
            $posts = array_slice($posts, 0, $entries);
        }
    }


    $y = '';
    $m = '';
    $d = '';
    if (strlen(get_settings('permalink_structure')) > 0) {
        $y = strval($_GET['year']);
        $m = strval($_GET['monthnum']);
        $d = strval($_GET['day']);

       /*  $y = $_GET['year'];
        $m = $_GET['monthnum'];
        $d = $_GET['day']; */


    } else {
        $y = strval(substr($_GET['m'], 0, 4));
        if (strlen($_GET['m']) > 4) {
            $m = strval(substr($_GET['m'], 4, 2));
        }
        if (strlen($_GET['m']) > 6) {
            $d = strval(substr($_GET['m'], 6, 2));
        }
    }


    if (  strlen($y) == 4 && strlen($m) != 2 && strlen($d) != 2  ) {
        $now       = $y.'-12-31 23:59:59';
        $last_day  = $y.'-01-01 00:00:00';
    } elseif (  strlen($y) == 4 && strlen($m) == 2 && strlen($d) != 2  ) {
        if ( checkdate($m, '31', $y) ) {
            $now        = $y.'-'.$m.'-31 23:59:59';
            $last_day   = $y.'-'.$m.'-01 00:00:00';
        } elseif ( checkdate($m, '30', $y) ) {
            $now        = $y.'-'.$m.'-30 23:59:59';
            $last_day   = $y.'-'.$m.'-01 00:00:00';
        } elseif ( checkdate($m, '29', $y) ) {
            $now        = $y.'-'.$m.'-29 23:59:59';
            $last_day   = $y.'-'.$m.'-01 00:00:00';
        } else {
            $now        = $y.'-'.$m.'-28 23:59:59';
            $last_day   = $y.'-'.$m.'-01 00:00:00';
        }
    } elseif (  strlen($y) == 4 && strlen($m) == 2 && strlen($d) == 2  ) {
        $now        = $y.'-'.$m.'-'.$d.' 23:59:59';
        $last_day   = $y.'-'.$m.'-'.$d.' 00:00:00';
    } else {
        $now = date('Y-m-d H:i:s',(time() + (get_settings('time_difference') * 3600)));
        $last_day = date('Y-m-d', strtotime($posts[count($posts)-1]->post_date)).' 00:00:00';
    }


    $sql = "SELECT ID, link_url, link_text, link_caption, link_rel, link_target, link_visible, date_added FROM $tablerecentlinks WHERE date_added < '$now' AND date_added > '$last_day' AND link_visible = 'Y' ORDER BY date_added DESC";


    $links = $wpdb->get_results($sql);



    if ($links) {

        for ($i=0; $i < count($links); $i++) {
            $links[$i]->link_text = stripslashes($links[$i]->link_text);
            $links[$i]->link_url = stripslashes($links[$i]->link_url);
            $links[$i]->link_caption = stripslashes($links[$i]->link_caption);
            $links[$i]->link_rel = stripslashes($links[$i]->link_rel);
            $links[$i]->link_target = stripslashes($links[$i]->link_target);

            if (strlen(get_settings('permalink_structure')) > 0) { // using mod_rewrite
                $links[$i]->link_permalink = get_settings('siteurl').'/recent-links/'.date('Y/m', strtotime($links[$i]->date_added)).'/#rlink-'.$links[$i]->ID;
            } else {
                $links[$i]->link_permalink = get_settings('siteurl').'/wp-recent-links.php?y='.date('Y', strtotime($links[$i]->date_added)).'&m='.date('m', strtotime($links[$i]->date_added)).'#rlink-'.$links[$i]->ID;
            }

            if (  is_int(strpos($links[$i]->link_url, '&'))  &&  !strpos($links[$i]->link_url, '&')  &&  !strpos($links[$i]->link_url, '&')  ) {
                $links[$i]->link_url = str_replace('&', '&', $links[$i]->link_url);
            }

            $links[$i]->link_text = strip_tags($links[$i]->link_text);
            $links[$i]->link_text = str_replace($a_tag, '', $links[$i]->link_text);
            $links[$i]->link_text = str_replace($a_tag2, '', $links[$i]->link_text);

        }
    }

    $_tmp_arr = array();
    $posts = array_merge($links, $posts);

    foreach ($posts as $post) {
        $_tmp_item = array();
        if (isset($post->post_date_gmt)) {
            //$_tmp_item['0000_sort'] = $post->post_date_gmt;
            $_tmp_item['0000_sort'] = $post->post_date;
            $_tmp_item['post_object'] = $post;
            $_tmp_item['rp_entry_type'] = 'entry';
        } elseif (isset($post->date_added)) {
            //$_tmp_item['0000_sort'] = date('Y-m-d H:i:s', (strtotime($post->date_added) - (get_settings('time_difference') * 3600)));
            $_tmp_item['0000_sort'] = $post->date_added;
            $_tmp_item['post_object'] = $post;
            $_tmp_item['rp_entry_type'] = 'link';
        }
        $_tmp_arr[] = $_tmp_item;
    }
    rsort($_tmp_arr);
    $posts = array();
    $i = 0;
    foreach ($_tmp_arr as $_tmp_item) {
        $posts[$i] = $_tmp_item['post_object'];
        $posts[$i]->rp_entry_type = $_tmp_item['rp_entry_type'];

        $i++;
    }

}



// -------------------------------------------------------------------------
//! Older functions, deprecated. Please try not to use!
// These are aliases for old functions (my-hacks.php days!)
// -------------------------------------------------------------------------

function rpmod_recentlinks($limit = 12, $before = '<li>', $after = '</li>', $between = "\n", $date_append = 'F j')
{
    return rp_recentlinks($limit, false, false, '', false, $date_append, $before, $after, $between);
}

function rpmod_recentlinks_archives_url()
{
    return rp_recentlinks_archives_url();
}

function rpmod_recentlinks_rss2_url()
{
    return rp_recentlinks_rss2_url();
}

function rpmod_recentlinks_month($limit = '', $before = '<li>', $after = '</li>', $between = "\n", $show_link_count = false)
{
    return rp_recentlinks_month($limit, false, false, true, '#', false, 'F j', $before, $after, $between);
}

function rpmod_recentlinks_archives($limit = '', $before = '<li>', $after = '</li>', $between = "\n", $show_link_count = false)
{
    return rp_recentlinks_archives($limit, $show_link_count, $before, $after, $between);
}



















/**************----------------  STANDALONE SECTION  ---------------**************/
// Thanks to Kitten's Spaminator I can now write a WP-1.5 plugin! :)


if (function_exists('is_plugin_page') && is_plugin_page()) { ?>
    <div class="wrap">
    <h2>Recent Links</h2>
    <p>A linklog plugin for WordPress, allowing you to have your own blog of
    links without the need for another wp-powered weblog or (gasp!) another
    weblog software. More information at the
    <a href="http://rebelpixel.com/projects/wp-recent-links/">project's page</a>.
    </p>
    </div>
<?php }
else {
    function rp_recentlinks_admin_menu() {
        add_submenu_page('post.php', 'Add Recent Link', 'Add Recent Link', 5, 'recent-links.php'); // adds to the Write menu
        add_management_page('Recent Links', 'Recent Links', 5, 'recent-links.php'); // adds to the Manage menu
    }
}
add_action('admin_menu', 'rp_recentlinks_admin_menu'); // runs the function to add those menus

/**************--------------  END STANDALONE SECTION  -------------**************/
?>